@@ -42,6 +42,30 @@ import copy
 import threading
 from collections import Iterable
 
+def padAndTruncateFloat(score, n):
+    score = str(score)
+    if len(score) > n:
+        score = score[:n]
+    if len(score) < n:
+        score += "0" * abs(len(score) - n)
+    return score
+
+def fieldCounts(l, field, logger=None, verbose=False):
+    counts = dict()
+    for current in l:
+        if field in current:
+            if current[field] not in counts:
+                counts[current[field]] = 0
+            counts[current[field]] += 1
+    if len(counts) == 0:
+        if verbose:
+            print("No data for field " + str(field))
+    else:
+        for field, count in counts.items():
+            if verbose:
+                print(str(field) + ": " + str(count))
+    return counts
+
 def strToInt(text):
     return sum([ord(e) for e in text])
 
@@ -135,13 +159,14 @@ def combine(voc, digits, strConcat=False):
         keys = __combine(keys, voc)
     return keys
 
-def shuffle(data, inplace=False):
-    """
-        TODO seed param
-    """
+def shuffle(data, inplace=False, seed=None):
+    if seed is None:
+        rd = random.Random()
+    else:
+        rd = random.Random(seed)
     if not inplace:
         data = copy.deepcopy(data)
-    random.shuffle(data)
+    rd.shuffle(data)
     return data
 
 def intByteSize(n):
@@ -1253,8 +1278,6 @@ def deleteDuplicate(l):
     return list(set(l))
 
 
-
-
 def strCheck(value):
     return value is not None and isinstance(value, str) and len(value) > 0
 
@@ -1269,6 +1292,8 @@ def mergeDicts(*dict_args):
 #         if dictionary is not None:
 #             result.update(dictionary)
 #     return result
+    if dict_args is not None and len(dict_args) == 1 and isinstance(dict_args[0], list):
+        dict_args = dict_args[0]
     result = {}
     for dictionary in dict_args:
         if dictionary is not None:
@@ -1590,9 +1615,12 @@ def associate(keys, values, multiValues=False, allowDuplicates=False, shift=0, l
         several time a value to keys, so each key will be used.
     """
     if not multiValues and len(values) > len(keys):
-        logWarning("Cannot associate values of size " + str(len(values))
-                   + " to keys of size " + str(len(keys))
-                   + ". You can set multiValues to True.", logger, verbose=verbose)
+        if verbose:
+            message = "Cannot associate values of size " + str(len(values)) + " to keys of size " + str(len(keys)) + ". You can set multiValues to True."
+            if logger is None:
+                print(message)
+            else:
+                logger.log(message)
     if multiValues and allowDuplicates:
         raise Exception("You cannot set multiValues as True and allowDuplicates as True")
     if not isinstance(keys, set):
